Stan Math Library: stan/math/prim/scal/prob/beta_binomial_rng.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
beta_binomial_rng.hpp File Reference
`#include <stan/math/prim/scal/err/check_consistent_sizes.hpp>`
`#include <stan/math/prim/scal/err/check_nonnegative.hpp>`
`#include <stan/math/prim/scal/err/check_positive_finite.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/fun/binomial_coefficient_log.hpp>`
`#include <stan/math/prim/scal/fun/digamma.hpp>`
`#include <stan/math/prim/scal/fun/lbeta.hpp>`
`#include <stan/math/prim/scal/fun/lgamma.hpp>`
`#include <stan/math/prim/scal/fun/value_of.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`
`#include <stan/math/prim/scal/prob/binomial_rng.hpp>`
`#include <stan/math/prim/scal/prob/beta_rng.hpp>`
`#include <stan/math/prim/scal/fun/F32.hpp>`
`#include <stan/math/prim/scal/fun/grad_F32.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<class RNG >
int | stan::math::beta_binomial_rng (const int N, const double alpha, const double beta, RNG &rng)

[ Stan Home Page ] © 2011–2016, Stan Development Team.